# Installation

### From sources

Download the latest LaVue version from https://github.com/jkotan/lavue .

Extract sources and run

      $ python setup.py install

### Debian packages

Debian Buster (and Stretch, Jessie) as well as Ubuntu Focal (and Bionic, Eoan, Disco, Cosmic, Xenial) packages can be found in the HDRI repository.

To install the debian packages, add the PGP repository key

      $ sudo su
      $ wget -q -O - http://repos.pni-hdri.de/debian_repo.pub.gpg | apt-key add -

and then download the corresponding source list, e.g.

      $ cd /etc/apt/sources.list.d

and

      $ wget http://repos.pni-hdri.de/buster-pni-hdri.list

or

      $ wget http://repos.pni-hdri.de/stretch-pni-hdri.list

respectively.

Finally,

      $ apt-get update
      $ apt-get install python-lavue

and for its tango controller

      $ apt-get install lavue-controller

for python 2.7 version. Please notice that PyTine debian package is not available for python 2.

Similarly

      $ apt-get update
      $ apt-get install python3-lavue

      $ apt-get install lavue3-controller

for python 3 version. Please notice that HiDRA debian package is not available for python 3 yet.

### From Pip

To install it from pip you need to install pyqt5 in advance, e.g.

    $ python3 -m venv myvenv
    $ . myvenv/bin/activate

    $ pip install pyqt5

    or

    $ pip install pyqt5==5.14

    and then

    $ pip install lavue

Moreover it is also good to install the following python packages:

    $ pip install fabio
    $ pip install pillow
    $ pip install pyFAI
    $ pip install lavuefilters
    $ pip install pytango